# Generated by Django 3.0.4 on 2020-03-26 15:14

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0050_deleted_progresses'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Mat_view',
        ),
    ]
