# Generated by Django 2.2.4 on 2019-08-30 16:52

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0037_auto_20190822_2250'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Messages_theme_access',
        ),
    ]
