# Generated by Django 2.2.5 on 2019-09-04 18:26

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0055_auto_20190904_1757'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='messages',
            unique_together=set(),
        ),
    ]
