# Generated by Django 2.2.5 on 2019-09-19 16:20

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('twits', '0018_auto_20190916_1759'),
    ]

    operations = [
        migrations.AlterField(
            model_name='chat_user_user_theme',
            name='theme',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='tracker.Messages_theme'),
        ),
    ]
