# Generated by Django 2.2.3 on 2019-07-03 16:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('refs', '0004_type_param_values'),
    ]

    operations = [
        migrations.RenameField(
            model_name='type_param',
            old_name='pick_list',
            new_name='value_map',
        ),
        migrations.RemoveField(
            model_name='type_param',
            name='exponent',
        ),
        migrations.RemoveField(
            model_name='type_param',
            name='precision',
        ),
        migrations.AddField(
            model_name='type_param',
            name='required',
            field=models.BooleanField(default=False),
        ),
    ]
