# Generated by Django 2.2.5 on 2019-09-03 19:00

from django.conf import settings
from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('tracker', '0043_messages_files'),
    ]

    operations = [
        migrations.AddField(
            model_name='messages',
            name='to_whom',
            field=isc_common.fields.related.ForeignKeyCascade(default=None, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
    ]
