# Generated by Django 2.2.4 on 2019-08-21 00:56

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('clndr', '0004_calendar_shits_days'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='day',
            name='begintime',
        ),
        migrations.RemoveField(
            model_name='day',
            name='endtime',
        ),
    ]
