# Generated by Django 3.0.3 on 2020-02-23 08:22

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('events', '0003_auto_20191118_1245'),
    ]

    operations = [
        migrations.AlterField(
            model_name='event_type_users',
            name='event_type',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='events.Event_types'),
        ),
    ]
