# Generated by Django 2.2.1 on 2019-05-17 18:02

from django.conf import settings
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('tracker', '0021_messages_whom'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='messages_whom',
            unique_together={('message', 'to_whom')},
        ),
    ]
