# Generated by Django 3.0.3 on 2020-02-08 14:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('one_c', '0016_remove_files_1c_id_old'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='documents_param_1c',
            unique_together=set(),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(('value', None), ('value_boolean', None), ('value_float', None), ('value_int', None), ('value_uuid', None)), fields=('type',), name='Documents_param_1c_unique_constraint_0'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(('value_boolean', None), ('value_float', None), ('value_int', None), ('value_uuid', None)), fields=('type', 'value'), name='Documents_param_1c_unique_constraint_1'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(('value', None), ('value_float', None), ('value_int', None), ('value_uuid', None)), fields=('type', 'value_boolean'), name='Documents_param_1c_unique_constraint_2'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(('value_float', None), ('value_int', None), ('value_uuid', None)), fields=('type', 'value', 'value_boolean'), name='Documents_param_1c_unique_constraint_3'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(('value', None), ('value_boolean', None), ('value_int', None), ('value_uuid', None)), fields=('type', 'value_float'), name='Documents_param_1c_unique_constraint_4'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(('value_boolean', None), ('value_int', None), ('value_uuid', None)), fields=('type', 'value', 'value_float'), name='Documents_param_1c_unique_constraint_5'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(('value', None), ('value_int', None), ('value_uuid', None)), fields=('type', 'value_boolean', 'value_float'), name='Documents_param_1c_unique_constraint_6'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(('value_int', None), ('value_uuid', None)), fields=('type', 'value', 'value_boolean', 'value_float'), name='Documents_param_1c_unique_constraint_7'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(('value', None), ('value_boolean', None), ('value_float', None), ('value_uuid', None)), fields=('type', 'value_int'), name='Documents_param_1c_unique_constraint_8'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(('value_boolean', None), ('value_float', None), ('value_uuid', None)), fields=('type', 'value', 'value_int'), name='Documents_param_1c_unique_constraint_9'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(('value', None), ('value_float', None), ('value_uuid', None)), fields=('type', 'value_boolean', 'value_int'), name='Documents_param_1c_unique_constraint_10'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(('value_float', None), ('value_uuid', None)), fields=('type', 'value', 'value_boolean', 'value_int'), name='Documents_param_1c_unique_constraint_11'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(('value', None), ('value_boolean', None), ('value_uuid', None)), fields=('type', 'value_float', 'value_int'), name='Documents_param_1c_unique_constraint_12'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(('value_boolean', None), ('value_uuid', None)), fields=('type', 'value', 'value_float', 'value_int'), name='Documents_param_1c_unique_constraint_13'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(('value', None), ('value_uuid', None)), fields=('type', 'value_boolean', 'value_float', 'value_int'), name='Documents_param_1c_unique_constraint_14'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(value_uuid=None), fields=('type', 'value', 'value_boolean', 'value_float', 'value_int'), name='Documents_param_1c_unique_constraint_15'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(('value', None), ('value_boolean', None), ('value_float', None), ('value_int', None)), fields=('type', 'value_uuid'), name='Documents_param_1c_unique_constraint_16'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(('value_boolean', None), ('value_float', None), ('value_int', None)), fields=('type', 'value', 'value_uuid'), name='Documents_param_1c_unique_constraint_17'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(('value', None), ('value_float', None), ('value_int', None)), fields=('type', 'value_boolean', 'value_uuid'), name='Documents_param_1c_unique_constraint_18'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(('value_float', None), ('value_int', None)), fields=('type', 'value', 'value_boolean', 'value_uuid'), name='Documents_param_1c_unique_constraint_19'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(('value', None), ('value_boolean', None), ('value_int', None)), fields=('type', 'value_float', 'value_uuid'), name='Documents_param_1c_unique_constraint_20'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(('value_boolean', None), ('value_int', None)), fields=('type', 'value', 'value_float', 'value_uuid'), name='Documents_param_1c_unique_constraint_21'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(('value', None), ('value_int', None)), fields=('type', 'value_boolean', 'value_float', 'value_uuid'), name='Documents_param_1c_unique_constraint_22'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(value_int=None), fields=('type', 'value', 'value_boolean', 'value_float', 'value_uuid'), name='Documents_param_1c_unique_constraint_23'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(('value', None), ('value_boolean', None), ('value_float', None)), fields=('type', 'value_int', 'value_uuid'), name='Documents_param_1c_unique_constraint_24'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(('value_boolean', None), ('value_float', None)), fields=('type', 'value', 'value_int', 'value_uuid'), name='Documents_param_1c_unique_constraint_25'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(('value', None), ('value_float', None)), fields=('type', 'value_boolean', 'value_int', 'value_uuid'), name='Documents_param_1c_unique_constraint_26'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(value_float=None), fields=('type', 'value', 'value_boolean', 'value_int', 'value_uuid'), name='Documents_param_1c_unique_constraint_27'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(('value', None), ('value_boolean', None)), fields=('type', 'value_float', 'value_int', 'value_uuid'), name='Documents_param_1c_unique_constraint_28'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(value_boolean=None), fields=('type', 'value', 'value_float', 'value_int', 'value_uuid'), name='Documents_param_1c_unique_constraint_29'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(condition=models.Q(value=None), fields=('type', 'value_boolean', 'value_float', 'value_int', 'value_uuid'), name='Documents_param_1c_unique_constraint_30'),
        ),
        migrations.AddConstraint(
            model_name='documents_param_1c',
            constraint=models.UniqueConstraint(fields=('type', 'value', 'value_boolean', 'value_float', 'value_int', 'value_uuid'), name='Documents_param_1c_unique_constraint_31'),
        ),
    ]
