# Generated by Django 2.2.3 on 2019-07-06 21:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('one_c', '0013_auto_20190706_2007'),
    ]

    operations = [
        migrations.AlterField(
            model_name='uuid_2_id',
            name='uuid',
            field=models.UUIDField(db_index=True, unique=True),
        ),
    ]
