# Generated by Django 2.2.3 on 2019-07-03 17:29

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('refs', '0005_auto_20190703_1646'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='type_param_values',
            name='type',
        ),
    ]
