# Generated by Django 2.2.4 on 2019-08-23 09:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('clndr', '0037_auto_20190823_0929'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='shift_day',
            unique_together=set(),
        ),
    ]
