# Generated by Django 3.0.2 on 2020-01-22 10:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('reports', '0003_auto_20200122_1029'),
    ]

    operations = [
        migrations.AlterField(
            model_name='jasper_reports',
            name='port',
            field=models.PositiveIntegerField(),
        ),
    ]
