# Generated by Django 2.2.4 on 2019-08-21 12:25

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('clndr', '0011_auto_20190821_0820'),
    ]

    operations = [
        migrations.AddField(
            model_name='holidays',
            name='props',
            field=bitfield.models.BitField((('holiday', 'Праздник'), ('shorted', 'Сокращенный')), db_index=True, default=None),
        ),
    ]
