# Generated by Django 2.2.3 on 2019-07-03 19:36

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('refs', '0006_remove_type_param_values_type'),
    ]

    operations = [
        migrations.AddField(
            model_name='type_param_values',
            name='type',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='refs.Type_param'),
        ),
    ]
