# Generated by Django 2.2.5 on 2019-09-03 21:26

from django.conf import settings
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('tracker', '0046_auto_20190903_1905'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='messages',
            unique_together={('guid', 'theme', 'state', 'message', 'user')},
        ),
    ]
